Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(255)

Unified Diff: remoting/host/desktop_resizer_linux.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/desktop_process_unittest.cc ('k') | remoting/host/desktop_resizer_mac.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/desktop_resizer_linux.cc
diff --git a/remoting/host/desktop_resizer_linux.cc b/remoting/host/desktop_resizer_linux.cc
index 13ce6a7179a53b3b4dff7237d3cef61e1a2e6a30..0afb32a63bf5435c1bf9552c33ca819c608d7f5d 100644
--- a/remoting/host/desktop_resizer_linux.cc
+++ b/remoting/host/desktop_resizer_linux.cc
@@ -66,7 +66,7 @@ namespace remoting {
// Wrapper class for the XRRScreenResources struct.
class ScreenResources {
public:
- ScreenResources() : resources_(NULL) {
+ ScreenResources() : resources_(nullptr) {
}
~ScreenResources() {
@@ -76,13 +76,13 @@ class ScreenResources {
bool Refresh(Display* display, Window window) {
Release();
resources_ = XRRGetScreenResources(display, window);
- return resources_ != NULL;
+ return resources_ != nullptr;
}
void Release() {
if (resources_) {
XRRFreeScreenResources(resources_);
- resources_ = NULL;
+ resources_ = nullptr;
}
}
@@ -142,7 +142,7 @@ class DesktopResizerLinux : public DesktopResizer {
// mode is in use, it is not deleted.
void DeleteMode(const char* name);
// Switch the primary output to the specified mode. If name is NULL, the
// primary output is disabled instead, which is required before changing
// its resolution.
void SwitchToMode(const char* name);
@@ -157,7 +157,7 @@ class DesktopResizerLinux : public DesktopResizer {
};
DesktopResizerLinux::DesktopResizerLinux()
- : display_(XOpenDisplay(NULL)),
+ : display_(XOpenDisplay(nullptr)),
screen_(DefaultScreen(display_)),
root_(RootWindow(display_, screen_)),
exact_resize_(base::CommandLine::ForCurrentProcess()->
@@ -263,7 +263,7 @@ void DesktopResizerLinux::SetResolution(const ScreenResolution& resolution) {
kDefaultDPI);
CreateMode(kTempModeName, resolution.dimensions().width(),
resolution.dimensions().height());
- SwitchToMode(NULL);
+ SwitchToMode(nullptr);
XRRSetScreenSize(display_, root_, resolution.dimensions().width(),
resolution.dimensions().height(), width_mm, height_mm);
SwitchToMode(kTempModeName);
@@ -311,7 +311,7 @@ void DesktopResizerLinux::DeleteMode(const char* name) {
void DesktopResizerLinux::SwitchToMode(const char* name) {
RRMode mode_id = None;
- RROutput* outputs = NULL;
+ RROutput* outputs = nullptr;
int number_of_outputs = 0;
if (name) {
mode_id = resources_.GetIdForMode(name);
@@ -142,7 +142,7 @@ class DesktopResizerLinux : public DesktopResizer {
// mode is in use, it is not deleted.
void DeleteMode(const char* name);
- // Switch the primary output to the specified mode. If name is NULL, the
+ // Switch the primary output to the specified mode. If name is nullptr, the
// primary output is disabled instead, which is required before changing
// its resolution.
« no previous file with comments | « remoting/host/desktop_process_unittest.cc ('k') | remoting/host/desktop_resizer_mac.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698